#!/usr/bin/python
# -*- coding: utf-8 -*-
import json
from django.utils.encoding import smart_unicode
from django.db.models import ProtectedError
from apella.management.utils import LoadDataCommand
from apella.models import ForeignDiplomaType


exempted = ['ΧΩΡΑ', '']


class Command(LoadDataCommand):

    def add_arguments(self, parser):
        parser.add_argument('json_file')

    def handle(self, *args, **options):

        # First delete all unused
        fdts = ForeignDiplomaType.objects.all()
        existing_before = fdts.count()
        deleted = 0
        for fdt in fdts:
            try:
                fdt.delete()
                deleted += 1
            except ProtectedError:
                continue

        file_path = options['json_file']
        with open(file_path) as json_file:
            data = json.load(json_file)
            data = data['data']
            added = 0
            existing = 0
            # Then load new ones
            for item in data:
                country = item[0]
                country = country.encode("utf-8").strip()
                if country in exempted:
                    continue
                diploma_title = item[1]
                diploma_title = diploma_title.encode("utf-8").strip()
                diploma_title_type = item[2]
                diploma_title_type = diploma_title_type.encode("utf-8").strip()

                try:
                    fdt = ForeignDiplomaType.objects.get(
                        country=country,
                        diploma_title=diploma_title,
                        diploma_title_type=diploma_title_type
                    )
                    existing += 1
                    continue
                except ForeignDiplomaType.DoesNotExist:
                    ForeignDiplomaType.objects.create(
                        country=country,
                        diploma_title=diploma_title,
                        diploma_title_type=diploma_title_type
                    )
                    added += 1
                    print("foreign diploma type created, country: %s"
                            ", diploma_title: %s, diploma_title_type: %s" 
                            % (country, diploma_title, diploma_title_type))

            print("Before: %i, Deleted: %i" % (existing_before, deleted))
            print("Added: %i, Existing: %i" % (added, existing))
